@@ -3,7 +3,7 @@ from astropy.utils import minversion
 
 
 class ModelBoundingBoxConverter(Converter):
-    tags = ("tag:stsci.edu:asdf/transform/property/bounding_box-1.0.0",)
+    tags = ("tag:stsci.edu:asdf/transform/property/bounding_box-*",)
     types = ("astropy.modeling.bounding_box.ModelBoundingBox",)
 
     def to_yaml_tree(self, bbox, tag, ctx):
@@ -40,7 +40,7 @@ class ModelBoundingBoxConverter(Converter):
 
 
 class CompoundBoundingBoxConverter(Converter):
-    tags = ("tag:stsci.edu:asdf/transform/property/compound_bounding_box-1.0.0",)
+    tags = ("tag:stsci.edu:asdf/transform/property/compound_bounding_box-*",)
     types = ("astropy.modeling.bounding_box.CompoundBoundingBox",)
 
     def to_yaml_tree(self, cbbox, tag, ctx):
